import { AESEncryptedString, VersionedObject } from "../businessObjects";
import { EBackupPriority } from "../enum";
import { UnixTimestamp, VolatileStorageKey } from "../primitives";
export interface IDataWalletBackupHeader {
    hash: string;
    timestamp: UnixTimestamp;
    signature: string;
    priority: EBackupPriority;
}
export interface IDataWalletBackup {
    header: IDataWalletBackupHeader;
    blob: AESEncryptedString | BackupBlob;
}
export declare enum EDataUpdateOpCode {
    UPDATE = 0,
    REMOVE = 1
}
export declare class VolatileDataUpdate {
    operation: EDataUpdateOpCode;
    value: VersionedObject | VolatileStorageKey;
    timestamp: number;
    priority: EBackupPriority;
    version?: number | undefined;
    constructor(operation: EDataUpdateOpCode, value: VersionedObject | VolatileStorageKey, timestamp: number, priority: EBackupPriority, version?: number | undefined);
}
export declare class FieldDataUpdate {
    key: string;
    value: string;
    timestamp: number;
    priority: EBackupPriority;
    constructor(key: string, value: string, timestamp: number, priority: EBackupPriority);
}
export declare type FieldMap = {
    [key: string]: FieldDataUpdate;
};
export declare type TableMap = {
    [key: string]: VolatileDataUpdate[];
};
export declare class BackupBlob {
    fields: FieldMap;
    records: TableMap;
    constructor(fields: FieldMap, records: TableMap);
}
export declare type BackupIndexEntry = {
    id: string;
    timestamp: number;
};
export declare type BackupIndex = {
    backups: {
        [key: string]: BackupIndexEntry;
    };
};
export declare type ModelTypes = {
    schemas: {
        DataWalletBackup: IDataWalletBackup;
        BackupIndex: AESEncryptedString;
    };
    definitions: {
        backupIndex: "BackupIndex";
    };
    tiles: Record<string, never>;
};
//# sourceMappingURL=IDataWalletBackup.d.ts.map